==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkLinearExtrusionFilter.java <==
// java wrapper for vtkLinearExtrusionFilter object
//

package vtk;
import vtk.*;

public class vtkLinearExtrusionFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExtrusionType_2(int id0);
  public void SetExtrusionType(int id0)
    { SetExtrusionType_2(id0); }

  private native int GetExtrusionTypeMinValue_3();
  public int GetExtrusionTypeMinValue()
    { return GetExtrusionTypeMinValue_3(); }

  private native int GetExtrusionTypeMaxValue_4();
  public int GetExtrusionTypeMaxValue()
    { return GetExtrusionTypeMaxValue_4(); }

  private native int GetExtrusionType_5();
  public int GetExtrusionType()
    { return GetExtrusionType_5(); }

  private native void SetExtrusionTypeToVectorExtrusion_6();
  public void SetExtrusionTypeToVectorExtrusion()
    { SetExtrusionTypeToVectorExtrusion_6(); }

  private native void SetExtrusionTypeToNormalExtrusion_7();
  public void SetExtrusionTypeToNormalExtrusion()
    { SetExtrusionTypeToNormalExtrusion_7(); }

  private native void SetExtrusionTypeToPointExtrusion_8();
  public void SetExtrusionTypeToPointExtrusion()
    { SetExtrusionTypeToPointExtrusion_8(); }

  private native void SetCapping_9(int id0);
  public void SetCapping(int id0)
    { SetCapping_9(id0); }

  private native int GetCapping_10();
  public int GetCapping()
    { return GetCapping_10(); }

  private native void CappingOn_11();
  public void CappingOn()
    { CappingOn_11(); }

  private native void CappingOff_12();
  public void CappingOff()
    { CappingOff_12(); }

  private native void SetScaleFactor_13(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_13(id0); }

  private native double GetScaleFactor_14();
  public double GetScaleFactor()
    { return GetScaleFactor_14(); }

  private native void SetVector_15(double id0,double id1,double id2);
  public void SetVector(double id0,double id1,double id2)
    { SetVector_15(id0,id1,id2); }

  private native void SetVector_16(double id0[]);
  public void SetVector(double id0[])
    { SetVector_16(id0); }

  private native double[] GetVector_17();
  public double[] GetVector()
    { return GetVector_17(); }

  private native void SetExtrusionPoint_18(double id0,double id1,double id2);
  public void SetExtrusionPoint(double id0,double id1,double id2)
    { SetExtrusionPoint_18(id0,id1,id2); }

  private native void SetExtrusionPoint_19(double id0[]);
  public void SetExtrusionPoint(double id0[])
    { SetExtrusionPoint_19(id0); }

  private native double[] GetExtrusionPoint_20();
  public double[] GetExtrusionPoint()
    { return GetExtrusionPoint_20(); }

  public vtkLinearExtrusionFilter() { super(); }

  public vtkLinearExtrusionFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkLinearExtrusionFilter.java <==
// java wrapper for vtkLinearExtrusionFilter object
//

package vtk;
import vtk.*;

public class vtkLinearExtrusionFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExtrusionType_2(int id0);
  public void SetExtrusionType(int id0)
    { SetExtrusionType_2(id0); }

  private native int GetExtrusionTypeMinValue_3();
  public int GetExtrusionTypeMinValue()
    { return GetExtrusionTypeMinValue_3(); }

  private native int GetExtrusionTypeMaxValue_4();
  public int GetExtrusionTypeMaxValue()
    { return GetExtrusionTypeMaxValue_4(); }

  private native int GetExtrusionType_5();
  public int GetExtrusionType()
    { return GetExtrusionType_5(); }

  private native void SetExtrusionTypeToVectorExtrusion_6();
  public void SetExtrusionTypeToVectorExtrusion()
    { SetExtrusionTypeToVectorExtrusion_6(); }

  private native void SetExtrusionTypeToNormalExtrusion_7();
  public void SetExtrusionTypeToNormalExtrusion()
    { SetExtrusionTypeToNormalExtrusion_7(); }

  private native void SetExtrusionTypeToPointExtrusion_8();
  public void SetExtrusionTypeToPointExtrusion()
    { SetExtrusionTypeToPointExtrusion_8(); }

  private native void SetCapping_9(int id0);
  public void SetCapping(int id0)
    { SetCapping_9(id0); }

  private native int GetCapping_10();
  public int GetCapping()
    { return GetCapping_10(); }

  private native void CappingOn_11();
  public void CappingOn()
    { CappingOn_11(); }

  private native void CappingOff_12();
  public void CappingOff()
    { CappingOff_12(); }

  private native void SetScaleFactor_13(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_13(id0); }

  private native double GetScaleFactor_14();
  public double GetScaleFactor()
    { return GetScaleFactor_14(); }

  private native void SetVector_15(double id0,double id1,double id2);
  public void SetVector(double id0,double id1,double id2)
    { SetVector_15(id0,id1,id2); }

  private native void SetVector_16(double id0[]);
  public void SetVector(double id0[])
    { SetVector_16(id0); }

  private native double[] GetVector_17();
  public double[] GetVector()
    { return GetVector_17(); }

  private native void SetExtrusionPoint_18(double id0,double id1,double id2);
  public void SetExtrusionPoint(double id0,double id1,double id2)
    { SetExtrusionPoint_18(id0,id1,id2); }

  private native void SetExtrusionPoint_19(double id0[]);
  public void SetExtrusionPoint(double id0[])
    { SetExtrusionPoint_19(id0); }

  private native double[] GetExtrusionPoint_20();
  public double[] GetExtrusionPoint()
    { return GetExtrusionPoint_20(); }

  public vtkLinearExtrusionFilter() { super(); }

  public vtkLinearExtrusionFilter(long id) { super(id); }
  public native long   VTKInit();

}
